@@ -9,19 +9,19 @@ from rest_framework.exceptions import ValidationError
 from rest_framework.fields import BooleanField, NullBooleanField
 from rest_framework.filters import BaseFilterBackend, OrderingFilter
 
-from dynamic_rest.utils import is_truthy
-from dynamic_rest.conf import settings
-from dynamic_rest.datastructures import TreeMap
-from dynamic_rest.fields import DynamicRelationField
-from dynamic_rest.meta import (
+from xtrm_drest.utils import is_truthy
+from xtrm_drest.conf import settings
+from xtrm_drest.datastructures import TreeMap
+from xtrm_drest.fields import DynamicRelationField
+from xtrm_drest.meta import (
     get_model_field,
     is_field_remote,
     is_model_field,
     get_related_model
 )
-from dynamic_rest.patches import patch_prefetch_one_level
-from dynamic_rest.prefetch import FastQuery, FastPrefetch
-from dynamic_rest.related import RelatedObject
+from xtrm_drest.patches import patch_prefetch_one_level
+from xtrm_drest.prefetch import FastQuery, FastPrefetch
+from xtrm_drest.related import RelatedObject
 
 patch_prefetch_one_level()
 
